@@ -13,6 +13,7 @@ from Cheese.Logger import Logger
 from Cheese.resourceManager import ResMan
 from Cheese.appSettings import Settings
 from Cheese.ErrorCodes import Error
+from Cheese.metadata import Metadata
 
 class AdminManager:
 
@@ -59,11 +60,8 @@ class AdminManager:
 
     @staticmethod
     def setAuth():
-        with open(ResMan.joinPath(ResMan.root(), "adminSettings.json"), "r") as f:
-            data = json.loads(f.read())
-
         AdminManager.users = []
-        for user in data["adminUsers"]:
+        for user in Metadata.admin["adminUsers"]:
             AdminManager.users.append(base64.b64encode(
                 bytes('%s:%s' % (user["name"], user["password"]), 'utf-8')).decode('ascii'))
 
