@@ -15,8 +15,13 @@ class Security:
 
         role = None
         dict = None
-        if (server.headers.get("Authorization") != None):
-            auth = Metadata.decode64(server.headers.get("Authorization"))
+        authHeader = server.headers.get("Authorization")
+        
+        if (authHeader.startswith("Basic ")):
+            authHeader = authHeader.replace("Basic ", "")
+
+        if (authHeader != None):
+            auth = Metadata.decode64(authHeader)
 
             for tp in Metadata.authentication["types"]:
                 dict = Security.fitPatern(auth, tp["patern"])
@@ -61,9 +66,9 @@ class Security:
             validation = validation.replace(f"${key}$", f"'{dict[key]}'")
 
         db = Database()
-        response = db.query(f"select case when exists ({validation}) then cast(1 as bit) else cast(0 as bit) end")
+        response = db.query(f"select case when exists ({validation}) then cast(1 as bit) else cast(0 as bit) end;")
         db.done()
-        return bool(response[0][0])
+        return bool(int(response[0][0]))
 
     @staticmethod
     def fitPatern(auth, patern):
